@@ -21,13 +21,15 @@ def process_dynamic_log_level(request):
         if settings.NIM_DJANGO_REQUEST_LOG_LEVEL_NAME in request.META:
             level_value = request.META.get(settings.NIM_DJANGO_REQUEST_LOG_LEVEL_NAME).upper()
             logger_message = logging.getLogger("django.request")
+            nim_headers = Utils.get_nim_headers(request)
             if level_value in ALLOWED_DYNAMIC_DEBUG_LEVEL_VALUES:
                 __update_log_level(logger_names, exclude_log_list, level_value)
                 logger_message.info("The log level has been overwritten by the header '{}' to the value {}".format(
-                    settings.NIM_DJANGO_REQUEST_LOG_LEVEL_NAME, level_value))
+                    settings.NIM_DJANGO_REQUEST_LOG_LEVEL_NAME, level_value), extra=nim_headers)
             else:
                 logger_message.info("The header '{}' has an invalid value, the values allowed are {}".format(
-                    settings.NIM_DJANGO_REQUEST_LOG_LEVEL_NAME, ", ".join(ALLOWED_DYNAMIC_DEBUG_LEVEL_VALUES)))
+                    settings.NIM_DJANGO_REQUEST_LOG_LEVEL_NAME, ", ".join(ALLOWED_DYNAMIC_DEBUG_LEVEL_VALUES)),
+                    extra=nim_headers)
 
 
 def dynamic_log_level():
